==> xlniuxdata-vipgame-1.0.1-20150205.075815-38-sources.jar: com/xunlei/niux/data/vipgame/dto/ProductDTO.java <==
package com.xunlei.niux.data.vipgame.dto;

public class ProductDTO {
	private String giftid;
	private String giftName;
	private long totalNum;
	private long remainNum;
	private long giftBonusNum;
	private long giftMoneyNum;
	private String giftImgUrl;
	private int giftType;
    private String valdateTime;
	
	public String getGiftid() {
		return giftid;
	}
	public void setGiftid(String giftid) {
		this.giftid = giftid;
	}
	public String getGiftName() {
		return giftName;
	}
	public void setGiftName(String giftName) {
		this.giftName = giftName;
	}
	public long getTotalNum() {
		return totalNum;
	}
	public void setTotalNum(long totalNum) {
		this.totalNum = totalNum;
	}
	public long getRemainNum() {
		return remainNum;
	}
	public void setRemainNum(long remainNum) {
		this.remainNum = remainNum;
	}
	public long getGiftBonusNum() {
		return giftBonusNum;
	}
	public void setGiftBonusNum(long giftBonusNum) {
		this.giftBonusNum = giftBonusNum;
	}
	public long getGiftMoneyNum() {
		return giftMoneyNum;
	}
	public void setGiftMoneyNum(long giftMoneyNum) {
		this.giftMoneyNum = giftMoneyNum;
	}
	public String getGiftImgUrl() {
		return giftImgUrl;
	}
	public void setGiftImgUrl(String giftImgUrl) {
		this.giftImgUrl = giftImgUrl;
	}
	public int getGiftType() {
		return giftType;
	}
	public void setGiftType(int giftType) {
		this.giftType = giftType;
	}

    public String getValdateTime() {
        return valdateTime;
    }

    public void setValdateTime(String valdateTime) {
        this.valdateTime = valdateTime;
    }
}

==> xlniuxdata-vipgame-1.0.21-20150731.090052-14-sources.jar: com/xunlei/niux/data/vipgame/dto/ProductDTO.java <==
package com.xunlei.niux.data.vipgame.dto;

public class ProductDTO {
	private String giftid;
	private String giftName;
	private long totalNum;
	private long remainNum;
	private long giftBonusNum;
	private long giftMoneyNum;
	private String giftImgUrl;
	private String smallImgUrl;
	private int giftType;
    private String valdateTime;
	
    
	public String getSmallImgUrl() {
		return smallImgUrl;
	}
	public void setSmallImgUrl(String smallImgUrl) {
		this.smallImgUrl = smallImgUrl;
	}
	public String getGiftid() {
		return giftid;
	}
	public void setGiftid(String giftid) {
		this.giftid = giftid;
	}
	public String getGiftName() {
		return giftName;
	}
	public void setGiftName(String giftName) {
		this.giftName = giftName;
	}
	public long getTotalNum() {
		return totalNum;
	}
	public void setTotalNum(long totalNum) {
		this.totalNum = totalNum;
	}
	public long getRemainNum() {
		return remainNum;
	}
	public void setRemainNum(long remainNum) {
		this.remainNum = remainNum;
	}
	public long getGiftBonusNum() {
		return giftBonusNum;
	}
	public void setGiftBonusNum(long giftBonusNum) {
		this.giftBonusNum = giftBonusNum;
	}
	public long getGiftMoneyNum() {
		return giftMoneyNum;
	}
	public void setGiftMoneyNum(long giftMoneyNum) {
		this.giftMoneyNum = giftMoneyNum;
	}
	public String getGiftImgUrl() {
		return giftImgUrl;
	}
	public void setGiftImgUrl(String giftImgUrl) {
		this.giftImgUrl = giftImgUrl;
	}
	public int getGiftType() {
		return giftType;
	}
	public void setGiftType(int giftType) {
		this.giftType = giftType;
	}

    public String getValdateTime() {
        return valdateTime;
    }

    public void setValdateTime(String valdateTime) {
        this.valdateTime = valdateTime;
    }
}
